@@ -316,6 +316,10 @@ class InputDatasetInterface(
             return InputDatasetInterface(**value)
         raise ValueError("Invalid input dataset definition.")
 
+    @staticmethod
+    def is_empty_fn(x):
+        return not all(i.is_shared for i in x.values())
+
     def create_reader(self):
         from pipelime.sequences import SamplesSequence
 
@@ -323,7 +327,7 @@ class InputDatasetInterface(
             folder=self.folder, merge_root_items=self.merge_root_items, must_exist=True
         )
         if self.skip_empty:
-            reader = reader.filter(lambda x: not all(i.is_shared for i in x.values()))
+            reader = reader.filter(InputDatasetInterface.is_empty_fn)
         if self.schema_ is not None:
             reader = self.schema_.append_validator(reader)
         return reader
@@ -709,11 +713,16 @@ class Interval(PydanticFieldWithDefaultMixin, pyd.BaseModel, extra="forbid"):
 
     start: t.Optional[int] = pyd.Field(
         None,
-        description="The first index (included), defaults to the first element (can be negative).",
+        description=(
+            "The first index (included), defaults to the first element "
+            "(can be negative)."
+        ),
     )
     stop: t.Optional[int] = pyd.Field(
         None,
-        description="The last index (excluded), defaults to the last element (can be negative).",
+        description=(
+            "The last index (excluded), defaults to the last element (can be negative)."
+        ),
     )
 
     @classmethod
